/*
 * Copyright 2009 the original author or authors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

import org.gradle.api.Plugin
import org.gradle.api.Project
import org.gradle.api.tasks.testing.Test

class AnsiColorConsoleLogPlugin implements Plugin<Project> {

    StopWatch watch

    void apply(Project project) {
        AnsiColor.init()
        project.ext.ansi = AnsiColor

        project.afterEvaluate {
            project.tasks.withType(Test).each { task ->
                // show standard out and standard error of the test JVM(s) on the console
                task.testLogging.showStandardStreams = true

                task.beforeTest { desc ->
                    def packageName = desc.className.replaceFirst(/\.[^.]*$/, '')
                    def shortenPackageName = packageName.split(/\./).collect { it[0] }.join(".")
                    def simpleClassName = desc.className.replaceFirst(/^.*\./, '')
                    AnsiColor.printlnAsTestResult """ - (${shortenPackageName}.${simpleClassName}) "${desc.name}" => """, true
                    watch = StopWatch.start()
                }
                task.afterTest { desc, result ->
                    AnsiColor.printlnAsTestResult "${result.resultType} (${String.format('%.3f', watch.wrap())} sec)"
                }
            }
        }
    }
}

